@@ -28,6 +28,10 @@
 
 #define noGPMP_VERBOSE
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <math.h>
 #include <libart_lgpl/art_affine.h>
 #include <gdk/gdkkeysyms.h>
