@@ -23,6 +23,10 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Cambridge, MA 02139, USA.
  */
 
+#ifdef HAVE_CONFIG_H
+#include <config.h>
+#endif
+
 #include <math.h>
 #include <libart_lgpl/art_misc.h>
 #include <libart_lgpl/art_vpath.h>
